@@ -95,17 +95,34 @@ def mock_get_descendant(
     api_host,
     entity_type,
     entity_id,
-    distance,
-    include_details,
+    distance=None,
+    include_details=True,
+    descendant_level=None,
+    include_historical=True,
 ):
-
     childs = [
             child
             for child in mock_entities[entity_type].values()
             if 119 in child["belongsTo"]
         ]
-    if include_details:
-        return childs
+
+    if entity_type == 'regions':
+        if descendant_level:
+            childs = [
+                child
+                for child in mock_entities[entity_type].values()
+                if child["level"] == descendant_level
+            ]
+        else:
+            childs = list(mock_entities["regions"].values())
+
+    if not include_historical or include_details:
+
+        if not include_historical:
+            childs = [child for child in childs if not child["historical"]]
+
+        if include_details:
+            return childs
     else:
         return [{"id": child["id"]} for child in childs]
 
@@ -115,45 +132,38 @@ def mock_get_ancestor(
     api_host,
     entity_type,
     entity_id,
-    distance,
-    include_details,
+    distance=None,
+    include_details=True,
+    ancestor_level=None,
+    include_historical=True,
 ):
-
     childs = [
             child
             for child in mock_entities[entity_type].values()
             if 12345 in child["contains"]
         ]
-    if include_details:
-        return childs
+
+    if entity_type == 'regions':
+        if ancestor_level:
+            childs = [
+                child
+                for child in mock_entities[entity_type].values()
+                if child["level"] == ancestor_level
+            ]
+        else:
+            childs = list(mock_entities["regions"].values())
+
+    if not include_historical or include_details:
+
+        if not include_historical:
+            childs = [child for child in childs if not child["historical"]]
+
+        if include_details:
+            return childs
     else:
         return [{"id": child["id"]} for child in childs]
 
 
-def mock_get_descendant_regions(
-    access_token,
-    api_host,
-    region_id,
-    descendant_level,
-    include_historical,
-    include_details,
-):
-    if descendant_level:
-        regions = [
-            region
-            for region in mock_entities["regions"].values()
-            if region["level"] == descendant_level
-        ]
-    else:
-        regions = list(mock_entities["regions"].values())
-    if not include_historical:
-        regions = [region for region in regions if not region["historical"]]
-    if include_details:
-        return regions
-    else:
-        return [{"id": region["id"]} for region in regions]
-
-
 def mock_get_available_timefrequency(access_token, api_host, **selection):
     return [
         {
@@ -238,10 +248,6 @@ def mock_get_data_points(access_token, api_host, **selections):
 @patch("groclient.lib.get_geojson", MagicMock(side_effect=mock_get_geojson))
 @patch("groclient.lib.get_ancestor", MagicMock(side_effect=mock_get_ancestor))
 @patch("groclient.lib.get_descendant", MagicMock(side_effect=mock_get_descendant))
-@patch(
-    "groclient.lib.get_descendant_regions",
-    MagicMock(side_effect=mock_get_descendant_regions),
-)
 @patch(
     "groclient.lib.get_available_timefrequency",
     MagicMock(side_effect=mock_get_available_timefrequency),
@@ -337,8 +343,6 @@ class GroClientTests(TestCase):
             "name"
             not in self.client.get_descendant('metrics', 119, include_details=False)[0]
         )
-
-    def test_get_descendant_regions(self):
         self.assertTrue("name" in self.client.get_descendant_regions(1215)[0])
         self.assertTrue(
             "name"
@@ -363,27 +367,23 @@ class GroClientTests(TestCase):
         df = self.client.get_df()
         self.assertEqual(df.iloc[0]["start_date"].date(), date(2017, 1, 1))
         self.client.add_single_data_series(mock_data_series[0])
-        df = self.client.get_df(show_revisions=True)
+        df = self.client.get_df(reporting_history=True)
         self.assertEqual(df.iloc[0]["start_date"].date(), date(2017, 1, 1))
         indexed_df = self.client.get_df(index_by_series=True)
         self.assertEqual(indexed_df.iloc[0]["start_date"].date(), date(2017, 1, 1))
         series = zip_selections(indexed_df.iloc[0].name)
         self.assertEqual(series, mock_data_series[0])
 
-    def test_get_df_show_revisions(self):
+    def test_get_df_complete_history(self):
         self.client.add_single_data_series(mock_data_series[0])
-        df = self.client.get_df(show_revisions=True)
-        self.assertEqual(df.iloc[0]["start_date"].date(), date(2017, 1, 1))
-
-    def test_get_df_show_available_date(self):
-        self.client.add_single_data_series(mock_data_series[0])
-        df = self.client.get_df(show_available_date=True)
-        self.assertEqual(df.iloc[0]["available_date"].date(), date(2017, 12, 31))
+        df = self.client.get_df(complete_history=True)
+        self.assertEqual(df.iloc[0]["reporting_date"].date(), date(2018, 1, 1))
+        self.assertEqual(df.iloc[0]["available_date"].date(), date(2018, 1, 31))
 
     def test_add_points_to_df(self):
         self.client.add_points_to_df(None, mock_data_series[0], [])
         self.assertTrue(self.client.get_df().empty)
-        self.assertTrue(self.client.get_df(show_revisions=True).empty)
+        self.assertTrue(self.client.get_df(reporting_history=True).empty)
         self.assertTrue(self.client.get_df(index_by_series=True).empty)
 
         data_points = self.client.get_data_points(**mock_data_series[0])
